# If the emacs-el package has installed a pkgconfig file, use that to determine
# install locations and Emacs version at build time, otherwise set defaults.
%if %($(pkg-config emacs) ; echo $?)
%define emacs_version 22.1
%define emacs_lispdir %{_datadir}/emacs/site-lisp
%define emacs_startdir %{emacs_lispdir}/site-start.d
%else
%define emacs_version %(pkg-config emacs --modversion)
%define emacs_lispdir %(pkg-config emacs --variable sitepkglispdir)
%define emacs_startdir %(pkg-config emacs --variable sitestartdir)
%endif

# AucTeX includes preview-latex which allows previeweing directly in the Emacs
# buffer. This makes use of preview.sty, a LaTeX class, which is also included
# with AucTex preview-latex can either use a privately installed copy of
# preview.sty, or it can use one installed in the system texmf tree. If the
# following is set to 1, an add-on LaTeX package will be created which installs
# into the system texmf tree, and preview-latex will use that. However, TeXLive
# already includes preview.sty and so this may not be desireable -- setting the
# following value to 0 means that preview-latex/AucTeX will use a privately
# installed copy of preview.sty.
%define separate_preview 1

Summary: 	Enhanced TeX modes for Emacs
Name: 		emacs-auctex
Version: 	11.85
Release: 	10%{?dist}
License: 	GPLv3+
Group: 		Applications/Editors
URL: 		http://www.gnu.org/software/auctex/
Obsoletes: 	auctex
Provides: 	auctex
Conflicts: 	emacspeak < 18
Requires: 	emacs(bin) >= %{emacs_version}
Requires:	ghostscript dvipng
Requires:	tex(latex) tex(dvips)
Requires(pre): 	/sbin/install-info 
Requires(post): /sbin/install-info
%if %{separate_preview}
Requires: 	tex-preview = %{version}-%{release}
%endif

Source0: 	ftp://ftp.gnu.org/pub/gnu/auctex/auctex-%{version}.tar.gz
BuildArch: 	noarch
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: 	emacs emacs-el texlive-latex texinfo-tex ghostscript

%description 
AUCTeX is an extensible package that supports writing and formatting
TeX files for most variants of Emacs.

AUCTeX supports many different TeX macro packages, including AMS-TeX,
LaTeX, Texinfo and basic support for ConTeXt.  Documentation can be
found under /usr/share/doc, e.g. the reference card (tex-ref.pdf) and
the FAQ. The AUCTeX manual is available in Emacs info (C-h i d m
AUCTeX RET). On the AUCTeX home page, we provide manuals in various
formats.

AUCTeX includes preview-latex support which makes LaTeX a tightly
integrated component of your editing workflow by visualizing selected
source chunks (such as single formulas or graphics) directly as images
in the source buffer.

This package is for GNU Emacs.

%package el
Summary: 	Elisp source files for %{name}
Group: 		Applications/Editors
Requires: 	%{name} = %{version}-%{release}

%description el
This package contains the source Elisp files for AUCTeX for Emacs.

%package doc
Summary:	Documentation in various formats for AUCTeX
Group:		Documentation

%description doc
Documentation for the AUCTeX package for emacs in various formats,
including HTML and PDF.

%if %{separate_preview}
%package -n tex-preview
Summary: 	Preview style files for LaTeX
Group: 		Applications/Publishing
Requires: 	tex(latex)
Obsoletes:	tetex-preview
Provides:	tetex-preview

%description -n tex-preview 
The preview package for LaTeX allows for the processing of selected
parts of a LaTeX input file.  This package extracts indicated pieces
from a source file (typically displayed equations, figures and
graphics) and typesets with their base point at the (1in,1in) magic
location, shipping out the individual pieces on separate pages without
any page markup.  You can produce either DVI or PDF files, and options
exist that will set the page size separately for each page.  In that
manner, further processing (as with Ghostscript or dvipng) will be
able to work in a single pass.

The main purpose of this package is the extraction of certain
environments (most notably displayed formulas) from LaTeX sources as
graphics. This works with DVI files postprocessed by either Dvips and
Ghostscript or dvipng, but it also works when you are using PDFTeX for
generating PDF files (usually also postprocessed by Ghostscript).

The tex-preview package is generated from the AUCTeX package for 
Emacs.
%endif

%prep
%setup -q -n auctex-%{version}

%build
%if %{separate_preview}
%configure --with-emacs 
%else
%configure --with-emacs --without-texmf-dir
%endif

make

# Build documentation in various formats
pushd doc
make extradist
popd

# Fix some encodings
iconv -f ISO-8859-1 -t UTF8 RELEASE > RELEASE.utf8 && touch -r RELEASE RELEASE.utf8 && mv RELEASE.utf8 RELEASE

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{emacs_startdir}
make DESTDIR=%{buildroot} install
rm -rf %{buildroot}%{_var}

# Remove /usr/share/doc/auctex directory from buildroot since we don't want doc
# files installed here
rm -rf %{buildroot}%{_docdir}/auctex

%clean
rm -rf %{buildroot}

%post
/sbin/install-info %{_infodir}/auctex.info %{_infodir}/dir 2>/dev/null || :
/sbin/install-info %{_infodir}/preview-latex.info %{_infodir}/dir 2>/dev/null || :

%preun
if [ $1 -eq 0 ]; then
  /sbin/install-info --delete %{_infodir}/auctex.info %{_infodir}/dir 2>/dev/null || :
  /sbin/install-info --delete %{_infodir}/preview-latex.info %{_infodir}/dir 2>/dev/null || :
fi

%if %{separate_preview}
%post -n tex-preview
/usr/bin/texhash > /dev/null 2>&1 || :

%postun -n tex-preview
/usr/bin/texhash > /dev/null 2>&1 || :
%endif

%files
%defattr(-,root,root,-)
%doc RELEASE COPYING README TODO FAQ CHANGES
%doc %{_infodir}/*.info*
%exclude %{_infodir}/dir
%{emacs_startdir}/*
%dir %{emacs_lispdir}/auctex
%dir %{emacs_lispdir}/auctex/style
%{emacs_lispdir}/auctex/*.elc
%{emacs_lispdir}/auctex/style/*.elc
%{emacs_lispdir}/auctex/.nosearch
%{emacs_lispdir}/auctex/style/.nosearch
%{emacs_lispdir}/auctex/images
%{emacs_lispdir}/tex-site.el
%if !%{separate_preview}
%{emacs_lispdir}/auctex/latex
%{emacs_lispdir}/auctex/doc
%endif

%files el
%defattr(-,root,root,-)
%{emacs_lispdir}/auctex/*.el
%{emacs_lispdir}/auctex/style/*.el

%if %{separate_preview}
%files -n tex-preview
%defattr(-,root,root,-)
%{_datadir}/texmf/tex/latex/preview
%{_datadir}/texmf/doc/latex/styles
%endif

%files doc
%defattr(-,root,root,-)
%doc doc/*.{dvi,ps,pdf}
%doc doc/html


%changelog

